---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. With the following config '...'
2. In the cli, enter: '....'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - Version [i.e., output of `discreetly --version` (cli) or `discreetly.__version` (library)]
 - Backend [e.g., aws, gcp]
 - Python version: [e.g. 2.7.16, 3.7.3`]
 - OS [e.g. Ubuntu 19.4, macOS, Windows 10]

**Additional context**
Add any other context about the problem here.
